package com.jenkins.demo.controller;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.Map;

/**
 * Health Check Controller
 * 提供应用程序健康检查接口
 */
@RestController
@RequestMapping("/api")
public class HealthController {
    
    /**
     * 健康检查接口
     * GET /api/health
     */
    @GetMapping("/health")
    public Map<String, Object> health() {
        return Map.of(
            "status", "UP",
            "timestamp", LocalDateTime.now().toString(),
            "application", "Jenkins Demo Application",
            "version", "1.0.0"
        );
    }
    
    /**
     * 应用信息接口
     * GET /api/info
     */
    @GetMapping("/info")
    public Map<String, Object> info() {
        return Map.of(
            "name", "Jenkins Demo Application",
            "description", "Spring Boot 3 应用程序用于Jenkins CI/CD流程演示",
            "version", "1.0.0",
            "java.version", System.getProperty("java.version"),
            "spring.profiles.active", System.getProperty("spring.profiles.active", "default")
        );
    }
    
    /**
     * 简单的欢迎接口
     * GET /api/welcome
     */
    @GetMapping("/welcome")
    public Map<String, String> welcome() {
        return Map.of(
            "message", "欢迎使用Jenkins Demo应用程序！",
            "description", "这是一个用于演示Jenkins CI/CD流程的Spring Boot应用程序"
        );
    }
}
